@@ -3,12 +3,13 @@ package HTML::FormWidgets;
 use 5.01;
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.24.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.25.%d', q$Rev: 1 $ =~ /\d+/gmx );
 use parent 'Class::Accessor::Fast';
 
 use Class::Load  qw( is_class_loaded load_class );
 use English      qw( -no_match_vars );
 use HTML::Accessors;
+use List::Util   qw( any );
 use Scalar::Util qw( blessed );
 use Try::Tiny;
 
@@ -63,7 +64,7 @@ my $_collect_items = sub {
    my ($nitems, $stack) = @_; my $html = $NUL; $nitems or return $NUL;
 
    for (1 .. $nitems) {
-      my $args = pop @{ $stack }; $html = ($args->{content} || $NUL).$html;
+      my $args = pop @{ $stack }; $html = ($args->{content} // $NUL).$html;
    }
 
    return $html;
@@ -356,8 +357,8 @@ sub new {
 sub add_hidden {
    my ($self, $name, $value) = @_;
 
-   my $key    = $self->options->{list_key} || 'items';
-   my $hidden = $self->options->{hidden  } || {}; $hidden->{ $key } ||= [];
+   my $key    = $self->options->{list_key} // 'items';
+   my $hidden = $self->options->{hidden  } // {}; $hidden->{ $key } //= [];
 
    push @{ $hidden->{ $key } }, {
       content => "\n".$self->hacc->input( {
@@ -377,7 +378,7 @@ sub add_literal_js {
    }
    else { $list = $config };
 
-   my $obj = $self->options->{js_object}; $self->options->{literal_js} ||= [];
+   my $obj = $self->options->{js_object}; $self->options->{literal_js} //= [];
 
    push @{ $self->options->{literal_js} },
       "${obj}.config.${js_class}[ '${id}' ] = { ${list} };";
@@ -385,9 +386,12 @@ sub add_literal_js {
 }
 
 sub add_optional_js {
-   my ($self, @args) = @_; $self->options->{optional_js} ||= [];
+   my ($self, @args) = @_; my $scripts = $self->options->{optional_js} //= [];
+
+   for my $file (@args) {
+      any { $_ eq $file } @{ $scripts } or push @{ $scripts }, $file;
+   }
 
-   push @{ $self->options->{optional_js} }, @args;
    return;
 }
 
@@ -515,12 +519,12 @@ sub render_tip {
 }
 
 sub uri_for {
-   my ($self, $url) = @_; defined $url or return;
+   my ($self, @args) = @_; defined $args[ 0 ] or return;
 
-   ($url !~ m{ \A http[s]?: }mx and defined $self->options->{uri_for})
-      and return $self->options->{uri_for}->( $url );
+   ($args[ 0 ] !~ m{ \A http[s]?: }mx and defined $self->options->{uri_for})
+      and return $self->options->{uri_for}->( @args );
 
-   return $url;
+   return $args[ 0 ];
 }
 
 1;
@@ -545,7 +549,7 @@ HTML::FormWidgets - Create HTML user interface components
 
 =head1 Version
 
-Describes version v0.24.$Rev: 1 $ of L<HTML::FormWidgets>
+Describes version v0.25.$Rev: 1 $ of L<HTML::FormWidgets>
 
 =head1 Synopsis
 
@@ -1159,10 +1163,11 @@ JavaScript class
 
 =head2 Template
 
-Look in C<templatedir> for a L<Template::Toolkit> template
+This provides for a "user defined" widget type.
+Looks in C<templatedir> for a L<Template::Toolkit> template
 called C<id> with a F<.tt> extension. Slurp it in and return
-it as the content for this widget. This provides for a "user defined"
-widget type
+it as the content for this widget. Alternatively take the template data
+from the C<text> attribute
 
 =head2 Textarea
 
@@ -1176,7 +1181,12 @@ to sixty characters wide (C<width>)
 
 =head2 Tree
 
-Implements an expanding tree of selectable objects
+Implements an expanding tree of selectable objects. The tree information is
+contained in the C<data> attribute which is a hash reference. If the data
+hash reference has an attribute C<_keys> then this array reference will contain
+the list of keys for this level of the tree in the correct display order. If
+this attribute is missing the keys in the C<data> hash reference are displayed
+in their natural sort order
 
 =head1 Diagnostics
 
