@@ -1,11 +1,8 @@
-# @(#)$Ident: Hidden.pm 2013-05-16 14:22 pjf ;
-
 package HTML::FormWidgets::Hidden;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
 sub init {
    my ($self, $args) = @_;
