@@ -1,28 +1,25 @@
-# @(#)$Ident: Label.pm 2013-05-16 14:22 pjf ;
-
 package HTML::FormWidgets::Label;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(dropcap) );
+__PACKAGE__->mk_accessors( qw( dropcap ) );
 
 sub init {
    my ($self, $args) = @_;
 
-   $self->class    ( q(label_text) );
-   $self->container( 0   );
-   $self->dropcap  ( 0   );
-   $self->text     ( q() );
+   $self->class    ( 'label_text' );
+   $self->container( 0 );
+   $self->dropcap  ( 0 );
+   $self->text     ( undef );
    return;
 }
 
 sub render_field {
-   my ($self, $args) = @_; my $text = $self->text or return;
+   my ($self, $args) = @_; my $text = $self->text;
 
-   $text =~ s{ \A \n }{}msx;
+   defined $text or return; $text =~ s{ \A \n }{}msx;
 
    if ($self->dropcap) {
       my $markup;
