@@ -1,13 +1,10 @@
-# @(#)$Ident: Textarea.pm 2013-05-16 14:20 pjf ;
-
 package HTML::FormWidgets::Textarea;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(cols config rows) );
+__PACKAGE__->mk_accessors( qw( cols config rows ) );
 
 sub init {
    my ($self, $args) = @_;
